@@ -14,7 +14,7 @@
 #'  integration will be referred to as the profile.
 #'  \item Divide the profile into N non-overlapping segments.
 #'  \item  Calculate the local trend for each of the segments using least-square regression.
-#'  Compute the total error for each of the segments.
+#'  Compute the total error for each ofi the segments.
 #'  \item Compute the average of the total error over all segments and take its root square. By repeating 
 #'  the previous steps for several segment sizes (let's denote it by t), we obtain the
 #'  so-called Fluctuation function \eqn{F(t)}.
@@ -33,31 +33,74 @@
 #' @param window.size.range Range of values for the windows size that will be used
 #' to estimate the fluctuation function. Default: c(10,300).
 #' @param do.plot logical value. If TRUE (default value), a plot of the Fluctuation function is shown.
+#' @param ... Additional graphical parameters.
 #' @return A \emph{dfa}  object.
 #' @author Constantino A. Garcia
 #' @examples
 #' \dontrun{
-#'  noise = rnorm(5000)
-#'  dfa.analysis = dfa(time.series = noise, npoints = 10, 
-#'                window.size.range=c(10,1000), do.plot=FALSE)
-#'  cat("Theorical: 0.5---Estimated: ", estimate(dfa.analysis),"\n")
+#'  white.noise = rnorm(5000)
+#' dfa.analysis = dfa(time.series = white.noise, npoints = 10, 
+#'                  window.size.range=c(10,1000), do.plot=FALSE)
+#' white.estimation = estimate(dfa.analysis,do.plot=TRUE)
+#' cat("Theorical: 0.5---Estimated: ",white.estimation ,"\n")
+#' 
+#' 
+#' library(fArma)
+#' fgn = as.numeric(fArma::fgnSim(n = 2000, H = 0.75))
+#' dfa.analysis = dfa(time.series = fgn, npoints = 30, 
+#'                    window.size.range=c(10,1000), 
+#'                    do.plot=FALSE)
+#' fgn.estimation = estimate(dfa.analysis, do.plot = TRUE,
+#'                           fit.col="blue",fit.lwd=2,fit.lty=2,
+#'                           main="Fitting DFA to fGn")
+#' cat("Theorical: 0.75---Estimated: ",fgn.estimation ,"\n")
+#' 
+#' 
+#' fbm = as.numeric(fArma::fbmSim(n = 2000, H = 0.25))
+#' dfa.analysis = dfa(time.series = fbm, npoints = 50, 
+#'                    window.size.range=c(10,300), 
+#'                    do.plot=FALSE)
+#' fbm.estimation = estimate(dfa.analysis,do.plot = TRUE,
+#'                           add.legend=F, main="DFA of fBm")
+#' cat("Theorical: 1.25 ---Estimated: ",fbm.estimation ,"\n")
+#' 
 #' }
 #' @rdname dfa
 #' @export dfa
 #' @exportClass dfa
-dfa=function(time.series, window.size.range=c(10,300), npoints=20,do.plot=TRUE){
+dfa=function(time.series, window.size.range=c(10,300), npoints=20,do.plot=TRUE,
+             ...){
   f="y~x"
   window.sizes=c()
   fluctuation.function=c()
   
-  #compute windows' sizes
-  log.window.sizes=seq(log10(window.size.range[[1]]),log10(window.size.range[[2]]),len=npoints)
-  window.sizes=10^log.window.sizes
-  # window.sizes must be an integer
-  window.sizes=unique(floor(window.sizes))
-  
+  if ( (window.size.range[[2]] < window.size.range[[1]]) || 
+         any(window.size.range < 1)){
+    stop("Invalid window size range")
+  }
+  # compute windows' sizes... 
+  if (npoints >= (window.size.range[[2]] - window.size.range[[1]] + 1)){
+    # compute Fn for all possible windows
+    window.sizes = window.size.range[[1]]:window.size.range[[2]]
+  }else{
+    # Try equally spaced windows in log scale
+    log.window.sizes = seq(log10(window.size.range[[1]]),
+                           log10(window.size.range[[2]]),
+                           len=npoints)
+    window.sizes = unique(round(10^log.window.sizes))
+    # if there are repeated elements we select missing windows until
+    # reaching npoints
+    if (length(window.sizes) < npoints){ 
+      missing = setdiff(window.size.range[[1]]:window.size.range[[2]],
+                        window.sizes)
+      points.needed = npoints - length(window.sizes) 
+      add.points = missing[seq(1,points.needed,len=points.needed)]
+      window.sizes = sort(c(window.sizes,add.points))
+    }
+  }
+  npoints = length(window.sizes)
   #integrate the time series time.series: this is called the "profile" in Penzel et al.
-  Y=calculateProfile(time.series)
+  Y=cumsum( time.series - mean(time.series) )
   
   #Calculate the local trend for
   #each of the segments by a least-square fit
@@ -69,10 +112,14 @@ dfa=function(time.series, window.size.range=c(10,300), npoints=20,do.plot=TRUE){
   #create dfa object
   dfa.structure = list(window.sizes=window.sizes,fluctuation.function=fluctuation.function)
   class(dfa.structure) = "dfa"
+  # add attributes
+  id=deparse(substitute(time.series))
+  attr(dfa.structure,"id") = id
+  
     
   #plot
   if (do.plot){
-    plot(dfa.structure)
+    plot(dfa.structure,...)
   }
   
   return(dfa.structure)
@@ -94,7 +141,7 @@ windowSizes = function(x){
 #' to detrend the time series. 
 #' @rdname dfa
 #' @method windowSizes dfa
-#' @S3method windowSizes dfa
+#' @export
 windowSizes.dfa = function(x){
   return (x$window.sizes)
 }
@@ -116,30 +163,39 @@ fluctuationFunction = function(x){
 #' obtained in the DFA represented by the \emph{dfa} object.
 #' @rdname dfa
 #' @method fluctuationFunction dfa
-#' @S3method fluctuationFunction dfa
+#' @export
 fluctuationFunction.dfa = function(x){
   return (x$fluctuation.function)
 }
 
 #' @rdname dfa
 #' @method plot dfa
-#' @param ... Additional parameters.
-#' @S3method plot dfa
+#' @param main A title for the plot.
+#' @param xlab A title for the x axis.
+#' @param ylab A title for the y axis.
+#' @param log A character string which contains "x" if the x axis is to be 
+#' logarithmic, "y" if the y axis is to be logarithmic and "xy" or "yx" if 
+#' both axes are to be logarithmic.
+#' @export
 #' 
-plot.dfa = function(x, ...){
-  plot(x$window.sizes,
-       x$fluctuation.function,log="xy",
-       main="Detrended fluctuation analysis\n",
-       xlab="Window size: t",
-       ylab="Fluctuation function: F(t)")
+plot.dfa = function(x, main="Detrended fluctuation analysis\n",
+                    xlab="Window size: t", ylab="Fluctuation function: F(t)",
+                    log="xy",...){
+  plot(x$window.sizes, x$fluctuation.function,
+       main=main,xlab=xlab,ylab=ylab,log=log,...)
 }
 #' @rdname dfa
 #' @method estimate dfa
 #' @param x A \emph{dfa} object.
 #' @param regression.range Vector with 2 components denoting the range where the function will perform linear regression.
-#' @S3method estimate dfa
+#' @param fit.col A colors to plot the regression line.
+#' @param fit.lty The type of line to plot the regression line.
+#' @param fit.lwd The width of the line for the regression line.
+#' @param add.legend add a legend with the resulting estmation to the plot?
+#' @export
 #' 
-estimate.dfa = function(x, regression.range = NULL,do.plot=FALSE,...){
+estimate.dfa = function(x, regression.range = NULL,do.plot=FALSE,
+                        fit.col=2,fit.lty=1,fit.lwd=1,add.legend=T,...){
   log.fluctuation.function = log10(x$fluctuation.function)
   log.window.sizes = log10(x$window.sizes)
   if (is.null(regression.range)){ regression.range = range(x$window.sizes)}
@@ -149,9 +205,13 @@ estimate.dfa = function(x, regression.range = NULL,do.plot=FALSE,...){
   interp1=lm(log.fluctuation.function[index.alpha]~log.window.sizes[index.alpha])
   alpha=interp1$coefficients[[2]]
   if (do.plot){
-    plot(x)
-    lines(x$window.sizes[index.alpha],10^interp1$fitted.values,col="blue")
-    legend("bottomright",col="blue",lty=c(1),lwd=c(2.5), legend=paste("Scaling exponent estimate =", sprintf("%.2f",alpha)))
+    plot(x,...)
+    lines(x$window.sizes[index.alpha],10^interp1$fitted.values,
+          col=fit.col,lty=fit.lty,lwd=fit.lwd)
+    if(add.legend){
+    legend("bottomright",col=fit.col,lty=fit.lty,lwd=fit.lwd,bty="n",
+           legend=paste("Scaling exponent estimate =", sprintf("%.2f",alpha)))
+    }
   }
   return(alpha)
 }
@@ -182,15 +242,3 @@ calculateFluctuationFunction=function(Y,fint,l){
   return (sqrt(sum(F2)/ngroups))
 }
 
-# private
-# Determine the “profile” of the timeseries time.series
-calculateProfile=function(time.series){
-  lendata=length(time.series)
-  time.series=time.series-mean(time.series)
-  #profile
-  Y=c(time.series[1])
-  for (i in (2:lendata)){
-    Y[i]=time.series[i]+Y[i-1]
-  }
-  return(Y)
-}
